@@ -1,8 +1,8 @@
 """Sqlalchemy2-datatables library, provides serverside implementation for jQuery Datatables"""
 
-__version__ = "0.1.0"
+__version__ = '0.3.0'
 
 from datatables.base import DTDataCallbacks
 from datatables.datatable import DataTable
 
-__all__ = ["DataTable", "DTDataCallbacks"]
+__all__ = ['DataTable', 'DTDataCallbacks']
